2 Temmuz 2018 Pazartesi

Kali ile Pentest Araçları: dnsenum

Dnsenum aracı whois bilgileri, reverse lookup, özel ip tanımlamaları, MX kaydı, NS kaydı, zone transfer, bind version vb.. birçok bilgi bulmaya ve bilgi olarak analiz etmenize olanak tanıyan Perl dilinde yazılmış bilgi toplama aracıdır.
Kali Linux üzerinde kurulu olarak gelmektedir.
Neler yapılabilir:
Host Adreslerine

Server Adlarına

Mail Adreslerine

Try Zone Bilgilerine

Subdomain Bilgilerine ulaşılabilir.

kurulum: apt-get install dnsenum
En çok  Kullanılan Parametreleri:
--enum : Google üzerinde subdomain arar.

-o : Parametre sonuçlarını .xml olarak kaydeder.

-f : Sözlük kullanarak bruteforce atak yapar.

-w : Whois bilgilerine ulaşır.

--dnsserver: Bu parametre dns ile arama yapar.

-r : Subdomainler için bruteforce kullanır.

-u : Update parametresi.
  • --dnsserver: hedef sunucu IP/domain adresi
  • --enum : Google sayfaları üzerinden araştırma
  • --noreverse: IP/Domain eşleştirmesini atla
  • --nocolor: Çıktılarda renk kullanma(beyaz renkte çıktı göster)
  • --private : Domain adresine ait IP adresleini ilgili alan kaydet.
  • --subfile: Sub domainleri ilgili alan kaydet.
  • --timeout: TCP ve UDP isteklerinde zaman aşım süresini belirler
  • --threads: Yapılan istekleri farklı kanallardan gerçekleştirir.
  • -v : Yapılan işlem ve hata mesajlarını detaylı gösterir.
  • GOOGLE Üzerinden Yapılan İşlemler
  • -p: Google sayfalarında arama yapma
  • -s: Google üzerinden subdomain araması için kullanma.
  • BRUTE-FORCE Ayarları
  • -f : Belirlediğiniz kelime listesinden subdomain testi yapar.
  • -u : Sonuçlar üzerinde güncelleme yapar.
  • -r : Subdomain leri recursive olarak bulmaya çalışır.
  • -d :İsteklerin bekleme süresi
  • -w: whois kayıtlarından sorgulama
  • -o: Çıktıları belirlenen alan yazma
Kullanımı: dnsenum <hedef site adresi>
örnek kullanımları
dnsenum --help, dnsenum -h :yardım ve paremetreleri
dnsenum hedefsite.com :genel kullanımı
dnsenum -w hedefsite.com: who isbilgileri ile
dnsenum --enum hedefsite.com: subdomain arar(google)
dnsenum --noreverse -o mydomain.xml hedefsite.com: geriye  doğru arama yapmadan sonuçları mydomain.xml dosyasına kaydet
dnsenum –f subdomain.txt –r hedefsite.com: önceden oluşturulan subdomain.txt dosyasındaki kelimelerle Brute Force denemesi yapar
dnsenum -s 5 -p 5 hedefsite.com: googlesayfalrında subdomain araması(dnsenum --enum hedefsite.com)
dnsenum hedefsite.com --enum -f dns.txt --update a -r hedefsite.com

1 Temmuz 2018 Pazar

hping:Pingin Ateşli Dünyası

 Ping komutunun ayrıntılı olanı hping.
Hping programı kullanılarak istenen sayıda  TCP/IP (Transmission Control Protocol - İletim Kontrol Protokolü) paketi hedefe gönderilir. TCP ping ve UDP ping’e göre daha aktif tarama gerçekleştirir. Aynı anda birden fazla kullanıcı taramaya elverişli olmamasına karşın nmap programı ile karşılaştırıldığında port taraması daha geniştir. Hping; "hping1",  "hping2" ve "hping3" olmak üzere üç versiyona sahiptir. RedHat ve Fedora işletim sistemlerinde #yum install hping komutu ile yükleme işlemi sağlanabilir. Ancak Debian işletim sistemi için #apt-get install hping3 komutunun çalıştırılması gerekir.
  • İstek üzerine TCP, UDP (User Datagram Protocol - Kullanıcı Veribloğu İletişim Protokolü), ICMP (Internet Control Message Protocol - İnternet Kontrol Mesaj Protokolü), "Raw-IP" paketleri üretebilir.
  • Güvenlik duvarına ve DoS (Denial of Servis - Hizmet Engelleme) saldırılara karşı performası artıran yapılandırmalar içerir.
  • Olası saldırı durumunda kısa sürede tespit edilip müdahale edebilir.
  • Oldukça gelişmiş port tarama ve dosya transferi özelliklerine sahiptir.
  • TCP/IP ile paketlerin toplanması ve bunların test edilmesini sağlar.
Sadece ICMP echo isteklerini gönderemez. TCP, UDP, ICMP ve RAW-IP protokollerini destekler, bir traceroute moduna, kapalı bir kanal ile diğer birçok özellik arasında dosya gönderme yeteneğine sahiptir.
Hping ile;
  • Güvenlik duvarı testi
  • Gelişmiş port taraması
  • Ağ testi, farklı protokoller, TOS, parçalanma kullanımı
  • Manuel yol MTU keşif
  • Desteklenen tüm protokoller altında gelişmiş traceroute
  • Uzaktan işletim sistemi parmak izi
  • Uzaktan çalışma zamanı tahmini
  • TCP / IP yığınları denetimi
  • Http, TCP / IP öğrenen öğrenciler için de yararlı olabilir.
Hping şu unix benzeri sistemlerde çalışır: Linux, FreeBSD, NetBSD, OpenBSD, Solaris, MacOs X, Windows. İndirmek için tıkla
  • hping -h komutu: komut yardımı
Hping ile gönderilen ilk paketle beraber TCP paket alışverişi başlatılmış olur. Bu bayraklar arası alışveriş o porttan tcpdump programı ile gözlenebilir. Bu şekilde tcpdump komutu ile gerçekleşen bayrak taşıma gözlemlenebilir.
TCP oturumunda en önemli bilesen bayrak(flags)lardır. Oturumun kurulması, veri aktarımı, baglantının koparılması vb gibi islerin tamamı bu bayraklar aracılıgı ile yapılır.  Hping kullanarak paket oluşturacağımız diğer protokollerde(IP, ICMP, UDP) bayrak tanımı yoktur.
Taşınan TCP bayrakları aşağıda açıklanmıştır.
SYN paketi (hping -S): TCP bağlantı isteğidir. İlk bağlantı bu paketle başlatılır.
ACK paketi (hping -A): Gelen paket isteğine, bu paket ile cevap verir.
RST paketi (hping -R): Bağlantıyı sıfırlar.
FIN paketi (hping -F): Bağlantıyı sonlandırır.
PUSH paketi (hping -P):
URG paketi (hping -U):
"SYN/ACK" paketi: Gelen SYN paketine karşılık SYN\ACK paketi gönderilerek bağlantı sağlanır.
"FIN"/ACK paketi: Gönderilen FIN paketine verilen bu paket gönderilerek karşılıklı oturum sonlandırılır.
"RST"/ACK paketi: Hedefe gönderilen RST paketi üzerine karşılıklı oturumu sıfırlamak üzere RST paketi gönderilir.
Push paketi (hping –P): Takılan paketlerin ilerlemesini sağlar.
URG paketi (hping -U): Hedefe ulaşmak için bekleme yapmadan önem sırasına öncelik verilerek geçmesi istenilen paketin iletimi sağlanır.
  • hping -c 3: 3 paket gönder.
  • hping --icmp <ipadresi> -K 0 -C 0 -c 4 : icmp echo request komutu çalıştırılarak ping taranması gerçekleştirilir. ICMP code ( -K ) ve ICMP type( -C ) değerlerini alır. Port taraması gerçekleşmez. (tcdump -i eth0 -c 3 -nn -vv host <ipadresi>) komutuyla gözlemlenebilir.
  • hping --udp -p 80 <ipadresi> -c 3: udp paketleri(bayraksız)
  • hping -S <ipadresi> -c 3: port durumu ve kullanılan portlar.
  • hping -I: Arayüze özgü sorgu yapmakta kullanılır.
  • hping -s: TCP\IP nin portunu  değiştirir.
  • hping -t: Paketlere istenilen TTL (Time to Live - Yaşama Süresi) değerleri atanır.
  • hping -V: Yapılan sorgulama hakkında ayrıntılı bilgi verir.
  • hping -n: Sayısal veri elde etmek için kullanılır.
  • hping -z: TTL değeri CTRL^z ile artar.
  • hping -v: Hping'in versiyonu hakkında bilgi verir.
Terimlerin açıklanması:
  • len: Dönen paketin boyutu.
  • ip: Paketi gönderen ip adresi(hedef sistem).
  • ttl: Paketin yaşam süresi.
  • DF: Parçalama biti aktif durumda.
  • Id: Ip paketine ait tanımlayıcı biricik(unique) bilgi.
  • Sport: Paketin gönderildiği kaynak port.
  • Flags: Aktif TCP bayrakları.
  • seq: Paketin sıra numarası.
  • win: Paketin pencere boyutu.
  • rtt: Milisaniye süresi.
hping çalışma modları:
-0  --rawip  Raw ip paketleri kullanmak için
-1  --icmp  Icmp Paketi oluşturmak için.
-2  --udp    UDP Paketleri oluşturmak için.
-8  –scan    Klasik  Tarama  modu.
-9  –listen   Dinleme modu
Örnekler:
hping –S –p 80 localhost  :80.porta SYN bayraklı paket göndermek için
hping -R -c 3 192.168.1.1 –p 80  : RST Bayraklı TCP paketleri olusturmak
hping -S -A localhost -p 80  :Aynı pakette birden fazla bayrak kullanımı. TCP paketleri oluştururken tek bayrak kullanılması zorunlu değildir. İstenirse tüm bayrakları set edilmiş TCP paketleri de üretilebilir(tabi bu paket firewallar tarafından düşürülecektir). Özellikle durum korumalı olmayan sistemleri test etmek için SYN/ACK , RST/ACK payraklı paketler kullanılabilir.
hping --icmp-addr -c 1 <ipadresi>  :subnet mask öğrenme
hping --udp -T <ipadresi> -p 53  : udp traceroute işlemi
hping -T 1  <ipadresi> -p 80 -S -n  : tcp  traceroute işlemi
hping --scan 22-1000 -S <ipadresi>  :Syncookie aktif olan makinlerde port tarama
hping -V --scan 1-22 -S <ipadresi>  : nmap gibi port tarama. -V paremetresi kaldırılırsa sadece açık portları listeler.
Gerçek IP ile hping --scan 22-1000 -S <ipadresi>, farklı IP ile hping --rand-source -p ++22 -S  <ipadresi>:Hping ile Port Taramalarında IPS/Firewall Şaşırtma
hping --tcp-timestamp <ipadresi> -p 80 -S -c 2 :Tcptimestamp taraması ile sistemlerin uptime sürelerini belirleme .(engellenmiş olabilir)
Bağlantılar:
https://drive.google.com/open?id=1rieN8LHFfuKEoYHcx1Ng7ITx9b6eJmB_
http://www.hping.org/
https://bidb.itu.edu.tr/eskiler/seyirdefteri/blog/2013/09/07/hping
https://www.slideshare.net/bgasecurity/module-hping-tcpippacketoyunlari
https://tools.kali.org/information-gathering/hping3
http://www.cozumpark.com/blogs/gvenlik/archive/2010/03/07/hping-kullanarak-tcp_3101_p-paketleriyle-oynama-b-l-m-1.aspx

traceroute görsel hali: Path Analzer Pro

Path Analyzer Pro, ağ sorunlarını araştırmak için performans testleri, DNS, whois ve ağ çözünürlüğü ile gelişmiş ağ rota izlemeyi sağlar.

Özellikler

  • Geleneksel traceroute'den 20 kata kadar daha hızlı
  • Etkileyicilerinizi etkilemek için çarpıcı rapor üretimi ve ihracatı
  • Windows ve MacOS X için kullanımı kolay grafik arayüzü
  • Canlı grafikler ağ sorunlarını belirginleştirir
  • Zum, pan ve detaylarla IP adreslerinin harita tabanlı konumu
  • Grafikler ve grafikler , performans testinden çıkarılan tahminleri alır
  • E-posta adresi izleme de dahil olmak üzere kolluk özel özellikleri
  • Filtrelerin, durum güvenlik duvarlarının ve diğer anormalliklerin otomatik olarak algılanması
  • Performans analizi için bir defa veya uzatılmış süre testi
  • Her protokol için min, max, avg ve standart sapma ölçümleri
  • Gerçek zamanlı yönlendirmeye dayalı otonom sistem sayılarını (ASN) çözer.

 Path Analyzer Pro ile

  • IP adresleri, e-posta adresleri ve ağ yolları araştırma
  • Ağ kullanılabilirliğini ve performans sorunlarını saptamak ve gidermek
  • ISS, yönlendirici veya sunucuda ki ağ sorunlarını belirleyin.
  • Bağlantılarınızı etkileyebilecek güvenlik duvarlarını ve diğer filtreleri bulun
  • Bir ağın yol özelliklerini görsel olarak analiz edin.
  • Grafik protokolü gecikmesi, titreşim ve diğer faktörler
  • Sadece IP atlamaları değil, gerçek uygulamaları ve bağlantı noktalarını izleme
  • Raporlar oluşturun, yazdırın ve dışa aktarın
  • Gerçek zamanlı raporlama ve geçmişle sürekli ve  eş zamanlı testler yapın.
Tam sürümü ücretlidir. ücretsiz deneme sürümünü indir.

Proje Başlığı Networkte İz Arama

İnternet üzerinde verilen kişisel bilgiye göre arama yapma sağlayan web portalı. Sosyal paylaşımları,  fotoğraf, video ve diğer tüm platformlardaki web üzerindeki bilgileri toplayıp rapor haline getirme.
Örnek sayfalar:
https://www.spokeo.com/
http://www.ussearch.com/ 'Türkiyeden çalışmıyor.
https://www.anywho.com/whitepages 'Türkiyeden çalışmıyor.

nslookup:Sadece DNS servisi düzgün çalışıyor mu diye kontrol için mi kullanılır?

nslookup: Dns Serverin Düzgün çalışıp çalışmadığı kontrol etmek için kullanılır.
2018-07-01_21-54-34.png
Bu komutu yazarak Enter’a bastığınızda DNS sunucunuz ve DNS adresinizin  hangisi olduğunu göreceksiniz.
NSLOOKUP komutunu çalıştırdıktan sonra DNS serverda ;
  • NS (name server) ,
  • SOA (start of authority) ,
  • A ,
  • CNAME sorguları yapılabilir.
Parametreleri nslookup komut satırına düştüğümüzde ‘help’ veya ‘?’ yazıp enter tuşuna bastığımızda listelenecektir ;
2018-07-01_22-04-17.png
AD              – varsayılan sunucuyu kullanarak AD adlı ana makine/etki alanı hakkında bilgi yazdırır
 AD1 AD2         – yukarıdaki gibi, ancak sunucu olarak AD2 kullanılır
 help veya ?   – sık kullanılan komutlar hakkında bilgi yazdırır
 set SEÇENEK     – seçenek ayarlar
 all                 – yazdırma seçenekleri, geçerli sunucu ve ana makine
[no]debug           – hata ayıklama bilgilerini yazdırır
   [no]d2              – ayrıntılı hata ayıklama bilgilerini yazdırır
[no]defname         – etki alanı adını her sorguya ekler
[no]recurse         – sorgu için yinelemeli yanıt ister
[no]search          – etki alanı arama listesini kullanır
[no]vc              – her zaman sanal bir devre kullanır
domain=AD           – varsayılan etki alanı adını AD olarak ayarlar
srchlist=N1[/N2/…/N6] – etki alanını N1 ve arama listesini N1, N2,
olarak ayarlar
  root=AD             – kök sunucusunu AD olarak ayarlar
retry=X             – deneme sayısını X olarak ayarlar
timeout=X           – başlangıç zaman aşımı aralığını X saniye olarak ayarlar
type=X              – sorgu türünü ayarlar (örneğin, A, ANY, CNAME, MX,
NS, PTR, SOA, SRV)
querytype=X         – type seçeneğiyle aynı
class=X             – sorgu sınıfını ayarlar (örneğin, IN (Internet), ANY)
[no]msxfr           – MS hızlı bölge aktarımını kullanır
ixfrver=X           – IXFR aktarım isteğinde kullanılacak geçerli sürüm
server AD       – geçerli varsayılan sunucuyu kullanarak, varsayılan sunucuyu AD olarak ayarlar
lserver AD      – başlangıç sunucusunu kullanarak, varsayılan sunucuyu AD olarak ayarlar
 finger [KULL.]  – geçerli varsayılan ana makinede isteğe bağlı AD’ı finger işlemine tutar
root            – varsayılan sunucuyu köke ayarlar
ls [opt] ETKİALANI [> DOSYA] – ETKİALANI’ndaki adresleri listeler(isteğe bağlı: çıktıyı
DOSYA’ya gönderir)
-a          –  kurallı adları ve diğer adları listeler
   -d          –  tüm kayıtları listeler
-t TYPE     –  verilen türdeki kayıtları listeler (örneğin, A, CNAME,
MX, NS, PTR vb.)
view DOSYA      – ‘ls’ çıktı dosyasını sıralar ve pg ile görüntüler
 exit            – programdan çıkar
Yukarıda listelenen komutlardan daha çok kullanılan komutlar aşağıdaki komutlardır ;
NS,Cname,vb. bilgileri sorgulayabileceğimiz
set type=<sorgu tipi> (NS, CNAME, vb.)  komutu veya
set type komutu ile aynı işlevi gören set q=X komutu


2018-07-01_22-15-24.png
2018-07-01_22-22-52.png
2018-07-01_22-25-25.png
2018-07-01_22-31-22.png
Benzetim: https://network-tools.com/nslook/